==> ecos-1.2.1.tar.bz2: ecos-1.2.1/packages/hal/sparclite/sleb/v1_2_1/include/hal_xpic.h <==
#ifndef CYGONCE_HAL_XPIC_H
#define CYGONCE_HAL_XPIC_H

//=============================================================================
//
//      hal_xpic.h
//
//      HAL eXternal Programmable Interrupt Controller support
//
//=============================================================================
//####COPYRIGHTBEGIN####
//
// -------------------------------------------
// The contents of this file are subject to the Cygnus eCos Public License
// Version 1.0 (the "License"); you may not use this file except in
// compliance with the License.  You may obtain a copy of the License at
// http://sourceware.cygnus.com/ecos
// 
// Software distributed under the License is distributed on an "AS IS"
// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the
// License for the specific language governing rights and limitations under
// the License.
// 
// The Original Code is eCos - Embedded Cygnus Operating System, released
// September 30, 1998.
// 
// The Initial Developer of the Original Code is Cygnus.  Portions created
// by Cygnus are Copyright (C) 1998,1999 Cygnus Solutions.  All Rights Reserved.
// -------------------------------------------
//
//####COPYRIGHTEND####
//=============================================================================
//#####DESCRIPTIONBEGIN####
//
// Author(s):   nickg, gthomas, hmt
// Contributors:        nickg, gthomas, hmt
// Date:        1999-01-28
// Purpose:     Define Interrupt support
// Description: The macros defined here provide the HAL APIs for handling
//              an external interrupt controller, and which interrupt is
//              used for what.
//              
// Usage:
//              #include <cyg/hal/hal_intr.h> // which includes this file
//              ...
//              
//
//####DESCRIPTIONEND####
//
//=============================================================================

#include <cyg/hal/hal_hwio.h> // HAL_SPARC_86940_READ/WRITE

//-----------------------------------------------------------------------------
// Interrupt controller access
// 
// In the Fuitsu SPARClite Evaluation Boards, when the external IRC (86940)
// is used (set Switch 1, position 8 (SW1#8)), interrupts are as follows:
// 
// 15   : NMI Push Switch (SW7)
// 14   : N_INT# Ethernet LAN Controller (MB86964)
// 13   : EX_IRQ13 from expansion board, active HIGH
// 12   : EX_IRQ12 from expansion board, active LOW
// 11   : EX_IRQ11 from expansion board, active LOW
// 10   : RRDY0 Serial CH0 receive ready signal
//  9   : TRDY0 Serial CH0 transmit ready signal
//  8   : TIMER1 Timer 1 output counter
//  7   : RRDY1 Serial CH1 receive ready signal
//  6   : TRDY1 Serial CH1 transmit ready signal
//  5   : EX_IRQ5 from expansion board, active LOW
//  4   : EX_IRQ4 from expansion board, active LOW
//  3   : EX_IRQ3 from expansion board, active HIGH
//  2   : EX_IRQ2 from expansion board, active LOW
//  1   : TIMER2 Timer 2 output counter

// The vector used by the Real time clock

//#define CYG_VECTOR_RTC                  CYG_VECTOR_INTERRUPT_8
#define CYGNUM_HAL_INTERRUPT_RTC       CYGNUM_HAL_VECTOR_INTERRUPT_8

#define HAL_SPARC_86940_REG_IRC_TRGM0 ( 0 * 4 )
#define HAL_SPARC_86940_REG_IRC_TRGM1 ( 1 * 4 )
#define HAL_SPARC_86940_REG_IRC_RQSNS ( 2 * 4 )
#define HAL_SPARC_86940_REG_IRC_RQCLR ( 3 * 4 )
#define HAL_SPARC_86940_REG_IRC_IMASK ( 4 * 4 )
#define HAL_SPARC_86940_REG_IRC_CLIRL ( 5 * 4 )

#define HAL_SPARC_86940_FLAG_CLIRL_CL (0x10)

#define HAL_SPARC_86940_IRC_IMASK_READ( r ) \
            HAL_SPARC_86940_READ( HAL_SPARC_86940_REG_IRC_IMASK, r )

#define HAL_SPARC_86940_IRC_IMASK_WRITE( v ) \
            HAL_SPARC_86940_WRITE( HAL_SPARC_86940_REG_IRC_IMASK, v )

#define HAL_SPARC_86940_IRC_RQSNS_READ( r ) \
            HAL_SPARC_86940_READ( HAL_SPARC_86940_REG_IRC_RQSNS, r )

#define HAL_SPARC_86940_IRC_RQCLR_WRITE( v ) \
            HAL_SPARC_86940_WRITE( HAL_SPARC_86940_REG_IRC_RQCLR, v )

#define HAL_SPARC_86940_IRC_CLIRL_READ( r ) \
            HAL_SPARC_86940_READ( HAL_SPARC_86940_REG_IRC_CLIRL, r )

#define HAL_SPARC_86940_IRC_CLIRL_WRITE( v ) \
            HAL_SPARC_86940_WRITE( HAL_SPARC_86940_REG_IRC_CLIRL, v )

//-----------------------------------------------------------------------------

#define HAL_INTERRUPT_MASK( _vector_ ) CYG_MACRO_START                      \
    cyg_uint32 _traps_, _mask_;                                             \
    HAL_DISABLE_TRAPS( _traps_ );                                           \
    HAL_SPARC_86940_IRC_IMASK_READ( _mask_ );                               \
    _mask_ |= (1 << (_vector_) );                                           \
    HAL_SPARC_86940_IRC_IMASK_WRITE( _mask_ );                              \
    HAL_SPARC_86940_IRC_RQCLR_WRITE( (1 << (_vector_) ) );                  \
    HAL_SPARC_86940_IRC_CLIRL_WRITE( HAL_SPARC_86940_FLAG_CLIRL_CL );       \
    HAL_RESTORE_INTERRUPTS( _traps_ );                                      \
CYG_MACRO_END

#define HAL_INTERRUPT_UNMASK( _vector_ ) CYG_MACRO_START                    \
    cyg_uint32 _traps_, _mask_;                                             \
    HAL_DISABLE_TRAPS( _traps_ );                                           \
    HAL_SPARC_86940_IRC_IMASK_READ( _mask_ );                               \
    _mask_ &=~ (1 << (_vector_) );                                          \
    HAL_SPARC_86940_IRC_IMASK_WRITE( _mask_ );                              \
    HAL_RESTORE_INTERRUPTS( _traps_ );                                      \
CYG_MACRO_END

#define HAL_INTERRUPT_ACKNOWLEDGE( _vector_ ) CYG_MACRO_START               \
    cyg_uint32 _traps_;                                                     \
    cyg_uint32 _req_, _irl_;                                                \
    HAL_DISABLE_TRAPS( _traps_ );                                           \
    HAL_SPARC_86940_IRC_RQCLR_WRITE( (1 << (_vector_) ) );                  \
    do {                                                                    \
        HAL_SPARC_86940_IRC_CLIRL_WRITE( HAL_SPARC_86940_FLAG_CLIRL_CL );   \
        HAL_SPARC_86940_IRC_RQSNS_READ( _req_ );                            \
        HAL_SPARC_86940_IRC_CLIRL_READ( _irl_ );                            \
        _req_ &= (1 << (_vector_)); /* if there really is a new intr  */    \
        _irl_ &= 0x0f;              /* then get out - else poll until */    \
    } while ( (!_req_) && (_irl_ == (_vector_)) ); /* no intr here    */    \
    HAL_RESTORE_INTERRUPTS( _traps_ );                                      \
CYG_MACRO_END

// Set an interrupt source's sensitivity:
// _level_ != 0 ? level-sensitive : edge-sensitive
// _up_    != 0 ? high/up : low/down
// SPARClite's 86940 has values as follows:
//    0  : high level
//    1  : low level
//    2  : rising edge
//    3  : falling edge
// TRGM0 controls sources 15-8, TRGM1 sources 7-1.

#define HAL_INTERRUPT_CONFIGURE( _vector_, _level_, _up_ ) CYG_MACRO_START  \
    int _reg_ = (8 > (_vector_)) ? HAL_SPARC_86940_REG_IRC_TRGM1            \
                                 : HAL_SPARC_86940_REG_IRC_TRGM0;           \
    int _val_, _myvect_ = (_vector_);                                       \
    cyg_uint32 _traps_;                                                     \
    HAL_DISABLE_TRAPS( _traps_ );                                           \
    (_myvect_) &= 7;                                                        \
    (_myvect_) <<= 1;                                                       \
    HAL_SPARC_86940_READ( _reg_, _val_ );                                   \
    _val_ &=~ (3 << (_myvect_));                                            \
    _val_ |= ( ((_level_) ? 0 : 2) + ((_up_) ? 0 : 1) ) << (_myvect_);      \
    HAL_SPARC_86940_WRITE( _reg_, _val_ );                                  \
    HAL_INTERRUPT_ACKNOWLEDGE( _vector_ );                                  \
    HAL_RESTORE_INTERRUPTS( _traps_ );                                      \
CYG_MACRO_END

// This is not a standard macro - platform dependent for debugging only:
//  o level, up tell you how this source was configured as above.
//  o hipri returns the number of the highest prio requesting interrupt
//  o mask tells you whether this source is masked off
//  o req tells you whether this source is requesting right now.
#define HAL_INTERRUPT_QUERY_INFO( _vector_, _level_, _up_,                  \
                                   _hipri_, _mask_, _req_ ) CYG_MACRO_START \
    int _reg_ = (8 > (_vector_)) ? HAL_SPARC_86940_REG_IRC_TRGM1            \
                                 : HAL_SPARC_86940_REG_IRC_TRGM0;           \
    int _val_, _myvect_ = (_vector_);                                       \
    HAL_SPARC_86940_IRC_IMASK_READ( _val_ );                                \
    _mask_ = (0 != ((1 << (_vector_)) & _val_ ));                           \
    HAL_SPARC_86940_IRC_RQSNS_READ( _val_ );                                \
    _req_ = (0 != ((1 << (_vector_)) & _val_ ));                            \
    HAL_SPARC_86940_IRC_CLIRL_READ( _hipri_ );                              \
    (_myvect_) &= 7;                                                        \
    (_myvect_) <<= 1;                                                       \
    HAL_SPARC_86940_READ( _reg_, _val_ );                                   \
    _val_ >>= (_myvect_);                                                   \
    (_level_) = !(_val_ & 2);                                               \
    (_up_)    = !(_val_ & 1);                                               \
CYG_MACRO_END

// This may set the priority of a vector to a particular level:
// SPARClite does not support this.
#define HAL_INTERRUPT_SET_LEVEL( _vector_, _level_ ) /* nothing */

//-----------------------------------------------------------------------------
#endif // ifndef CYGONCE_HAL_XPIC_H
// End of hal_xpic.h

==> ecos-1.3.1.tar.bz2: ecos-1.3.1/packages/hal/sparclite/sleb/v1_3_1/include/hal_xpic.h <==
#ifndef CYGONCE_HAL_XPIC_H
#define CYGONCE_HAL_XPIC_H

//=============================================================================
//
//      hal_xpic.h
//
//      HAL eXternal Programmable Interrupt Controller support
//
//=============================================================================
//####COPYRIGHTBEGIN####
//                                                                          
// -------------------------------------------                              
// The contents of this file are subject to the Red Hat eCos Public License 
// Version 1.1 (the "License"); you may not use this file except in         
// compliance with the License.  You may obtain a copy of the License at    
// http://www.redhat.com/                                                   
//                                                                          
// Software distributed under the License is distributed on an "AS IS"      
// basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the 
// License for the specific language governing rights and limitations under 
// the License.                                                             
//                                                                          
// The Original Code is eCos - Embedded Configurable Operating System,      
// released September 30, 1998.                                             
//                                                                          
// The Initial Developer of the Original Code is Red Hat.                   
// Portions created by Red Hat are                                          
// Copyright (C) 1998, 1999, 2000 Red Hat, Inc.                             
// All Rights Reserved.                                                     
// -------------------------------------------                              
//                                                                          
//####COPYRIGHTEND####
//=============================================================================
//#####DESCRIPTIONBEGIN####
//
// Author(s):   nickg, gthomas, hmt
// Contributors:        nickg, gthomas, hmt
// Date:        1999-01-28
// Purpose:     Define Interrupt support
// Description: The macros defined here provide the HAL APIs for handling
//              an external interrupt controller, and which interrupt is
//              used for what.
//              
// Usage:
//              #include <cyg/hal/hal_intr.h> // which includes this file
//              ...
//              
//
//####DESCRIPTIONEND####
//
//=============================================================================

#include <cyg/hal/hal_hwio.h> // HAL_SPARC_86940_READ/WRITE

//-----------------------------------------------------------------------------
// Interrupt controller access
// 
// In the Fuitsu SPARClite Evaluation Boards, when the external IRC (86940)
// is used (set Switch 1, position 8 (SW1#8)), interrupts are as follows:
// 
// 15   : NMI Push Switch (SW7)
// 14   : N_INT# Ethernet LAN Controller (MB86964)
// 13   : EX_IRQ13 from expansion board, active HIGH
// 12   : EX_IRQ12 from expansion board, active LOW
// 11   : EX_IRQ11 from expansion board, active LOW
// 10   : RRDY0 Serial CH0 receive ready signal
//  9   : TRDY0 Serial CH0 transmit ready signal
//  8   : TIMER1 Timer 1 output counter
//  7   : RRDY1 Serial CH1 receive ready signal
//  6   : TRDY1 Serial CH1 transmit ready signal
//  5   : EX_IRQ5 from expansion board, active LOW
//  4   : EX_IRQ4 from expansion board, active LOW
//  3   : EX_IRQ3 from expansion board, active HIGH
//  2   : EX_IRQ2 from expansion board, active LOW
//  1   : TIMER2 Timer 2 output counter

// The vector used by the Real time clock

//#define CYG_VECTOR_RTC                  CYG_VECTOR_INTERRUPT_8
#define CYGNUM_HAL_INTERRUPT_RTC       CYGNUM_HAL_VECTOR_INTERRUPT_8

#define HAL_SPARC_86940_REG_IRC_TRGM0 ( 0 * 4 )
#define HAL_SPARC_86940_REG_IRC_TRGM1 ( 1 * 4 )
#define HAL_SPARC_86940_REG_IRC_RQSNS ( 2 * 4 )
#define HAL_SPARC_86940_REG_IRC_RQCLR ( 3 * 4 )
#define HAL_SPARC_86940_REG_IRC_IMASK ( 4 * 4 )
#define HAL_SPARC_86940_REG_IRC_CLIRL ( 5 * 4 )

#define HAL_SPARC_86940_FLAG_CLIRL_CL (0x10)

#define HAL_SPARC_86940_IRC_IMASK_READ( r ) \
            HAL_SPARC_86940_READ( HAL_SPARC_86940_REG_IRC_IMASK, r )

#define HAL_SPARC_86940_IRC_IMASK_WRITE( v ) \
            HAL_SPARC_86940_WRITE( HAL_SPARC_86940_REG_IRC_IMASK, v )

#define HAL_SPARC_86940_IRC_RQSNS_READ( r ) \
            HAL_SPARC_86940_READ( HAL_SPARC_86940_REG_IRC_RQSNS, r )

#define HAL_SPARC_86940_IRC_RQCLR_WRITE( v ) \
            HAL_SPARC_86940_WRITE( HAL_SPARC_86940_REG_IRC_RQCLR, v )

#define HAL_SPARC_86940_IRC_CLIRL_READ( r ) \
            HAL_SPARC_86940_READ( HAL_SPARC_86940_REG_IRC_CLIRL, r )

#define HAL_SPARC_86940_IRC_CLIRL_WRITE( v ) \
            HAL_SPARC_86940_WRITE( HAL_SPARC_86940_REG_IRC_CLIRL, v )

//-----------------------------------------------------------------------------

#define HAL_INTERRUPT_MASK( _vector_ ) CYG_MACRO_START                      \
    cyg_uint32 _traps_, _mask_;                                             \
    HAL_DISABLE_TRAPS( _traps_ );                                           \
    HAL_SPARC_86940_IRC_IMASK_READ( _mask_ );                               \
    _mask_ |= (1 << (_vector_) );                                           \
    HAL_SPARC_86940_IRC_IMASK_WRITE( _mask_ );                              \
    HAL_SPARC_86940_IRC_RQCLR_WRITE( (1 << (_vector_) ) );                  \
    HAL_SPARC_86940_IRC_CLIRL_WRITE( HAL_SPARC_86940_FLAG_CLIRL_CL );       \
    HAL_RESTORE_INTERRUPTS( _traps_ );                                      \
CYG_MACRO_END

#define HAL_INTERRUPT_UNMASK( _vector_ ) CYG_MACRO_START                    \
    cyg_uint32 _traps_, _mask_;                                             \
    HAL_DISABLE_TRAPS( _traps_ );                                           \
    HAL_SPARC_86940_IRC_IMASK_READ( _mask_ );                               \
    _mask_ &=~ (1 << (_vector_) );                                          \
    HAL_SPARC_86940_IRC_IMASK_WRITE( _mask_ );                              \
    HAL_RESTORE_INTERRUPTS( _traps_ );                                      \
CYG_MACRO_END

#define HAL_INTERRUPT_ACKNOWLEDGE( _vector_ ) CYG_MACRO_START               \
    cyg_uint32 _traps_;                                                     \
    cyg_uint32 _req_, _irl_;                                                \
    HAL_DISABLE_TRAPS( _traps_ );                                           \
    HAL_SPARC_86940_IRC_RQCLR_WRITE( (1 << (_vector_) ) );                  \
    do {                                                                    \
        HAL_SPARC_86940_IRC_CLIRL_WRITE( HAL_SPARC_86940_FLAG_CLIRL_CL );   \
        HAL_SPARC_86940_IRC_RQSNS_READ( _req_ );                            \
        HAL_SPARC_86940_IRC_CLIRL_READ( _irl_ );                            \
        _req_ &= (1 << (_vector_)); /* if there really is a new intr  */    \
        _irl_ &= 0x0f;              /* then get out - else poll until */    \
    } while ( (!_req_) && (_irl_ == (_vector_)) ); /* no intr here    */    \
    HAL_RESTORE_INTERRUPTS( _traps_ );                                      \
CYG_MACRO_END

// Set an interrupt source's sensitivity:
// _level_ != 0 ? level-sensitive : edge-sensitive
// _up_    != 0 ? high/up : low/down
// SPARClite's 86940 has values as follows:
//    0  : high level
//    1  : low level
//    2  : rising edge
//    3  : falling edge
// TRGM0 controls sources 15-8, TRGM1 sources 7-1.

#define HAL_INTERRUPT_CONFIGURE( _vector_, _level_, _up_ ) CYG_MACRO_START  \
    int _reg_ = (8 > (_vector_)) ? HAL_SPARC_86940_REG_IRC_TRGM1            \
                                 : HAL_SPARC_86940_REG_IRC_TRGM0;           \
    int _val_, _myvect_ = (_vector_);                                       \
    cyg_uint32 _traps_;                                                     \
    HAL_DISABLE_TRAPS( _traps_ );                                           \
    (_myvect_) &= 7;                                                        \
    (_myvect_) <<= 1;                                                       \
    HAL_SPARC_86940_READ( _reg_, _val_ );                                   \
    _val_ &=~ (3 << (_myvect_));                                            \
    _val_ |= ( ((_level_) ? 0 : 2) + ((_up_) ? 0 : 1) ) << (_myvect_);      \
    HAL_SPARC_86940_WRITE( _reg_, _val_ );                                  \
    HAL_INTERRUPT_ACKNOWLEDGE( _vector_ );                                  \
    HAL_RESTORE_INTERRUPTS( _traps_ );                                      \
CYG_MACRO_END

// This is not a standard macro - platform dependent for debugging only:
//  o level, up tell you how this source was configured as above.
//  o hipri returns the number of the highest prio requesting interrupt
//  o mask tells you whether this source is masked off
//  o req tells you whether this source is requesting right now.
#define HAL_INTERRUPT_QUERY_INFO( _vector_, _level_, _up_,                  \
                                   _hipri_, _mask_, _req_ ) CYG_MACRO_START \
    int _reg_ = (8 > (_vector_)) ? HAL_SPARC_86940_REG_IRC_TRGM1            \
                                 : HAL_SPARC_86940_REG_IRC_TRGM0;           \
    int _val_, _myvect_ = (_vector_);                                       \
    HAL_SPARC_86940_IRC_IMASK_READ( _val_ );                                \
    _mask_ = (0 != ((1 << (_vector_)) & _val_ ));                           \
    HAL_SPARC_86940_IRC_RQSNS_READ( _val_ );                                \
    _req_ = (0 != ((1 << (_vector_)) & _val_ ));                            \
    HAL_SPARC_86940_IRC_CLIRL_READ( _hipri_ );                              \
    (_myvect_) &= 7;                                                        \
    (_myvect_) <<= 1;                                                       \
    HAL_SPARC_86940_READ( _reg_, _val_ );                                   \
    _val_ >>= (_myvect_);                                                   \
    (_level_) = !(_val_ & 2);                                               \
    (_up_)    = !(_val_ & 1);                                               \
CYG_MACRO_END

// This may set the priority of a vector to a particular level:
// SPARClite does not support this.
#define HAL_INTERRUPT_SET_LEVEL( _vector_, _level_ ) /* nothing */

//-----------------------------------------------------------------------------
#endif // ifndef CYGONCE_HAL_XPIC_H
// End of hal_xpic.h
